import re

class Normalizer:
    """
    Kurdish normalizer class.
    """

    def __init__(self):
        self.translation_src = "ؠػػؽؾؿكيٮٯٷٸٹٺٻټٽٿڀځٵٶٷٸٹٺٻټٽٿڀځڂڅڇڈډڊڋڌڍڎڏڐڑڒړڔڕږڗڙښڛڜڝڞڟڠڡڢڣڤڥڦڧڨڪګڬڭڮڰڱڲڳڴڵڶڷڸڹںڻڼڽھڿہۂۃۄۅۆۇۈۉۊۋۏۍێېۑےۓەۮۯۺۻۼۿݐݑݒݓݔݕݖݗݘݙݚݛݜݝݞݟݠݡݢݣݤݥݦݧݨݩݪݫݬݭݮݯݰݱݲݳݴݵݶݷݸݹݺݻݼݽݾݿࢠࢡࢢࢣࢤࢥࢦࢧࢨࢩࢪࢫࢮࢯࢰࢱࢬࢲࢳࢴࢶࢷࢸࢹࢺࢻࢼࢽﭐﭑﭒﭓﭔﭕﭖﭗﭘﭙﭚﭛﭜﭝﭞﭟﭠﭡﭢﭣﭤﭥﭦﭧﭨﭩﭮﭯﭰﭱﭲﭳﭴﭵﭶﭷﭸﭹﭺﭻﭼﭽﭾﭿﮀﮁﮂﮃﮄﮅﮆﮇﮈﮉﮊﮋﮌﮍﮎﮏﮐﮑﮒﮓﮔﮕﮖﮗﮘﮙﮚﮛﮜﮝﮞﮟﮠﮡﮢﮣﮤﮥﮦﮧﮨﮩﮪﮫﮬﮭﮮﮯﮰﮱﺀﺁﺃﺄﺅﺆﺇﺈﺉﺊﺋﺌﺍﺎﺏﺐﺑﺒﺕﺖﺗﺘﺙﺚﺛﺜﺝﺞﺟﺠﺡﺢﺣﺤﺥﺦﺧﺨﺩﺪﺫﺬﺭﺮﺯﺰﺱﺲﺳﺴﺵﺶﺷﺸﺹﺺﺻﺼﺽﺾﺿﻀﻁﻂﻃﻄﻅﻆﻇﻈﻉﻊﻋﻌﻍﻎﻏﻐﻑﻒﻓﻔﻕﻖﻗﻘﻙﻚﻛﻜﻝﻞﻟﻠﻡﻢﻣﻤﻥﻦﻧﻨﻩﻪﻫﻬﻭﻮﻯﻰﻱﻲﻳﻴىكي“” "
        self.translation_dst = (
            'یککیییکیبقویتتبتتتبحاوویتتبتتتبحححچدددددددددررررررررسسسصصطعففففففققکککککگگگگگللللنننننهچهههوووووووووییییییهدرشضغهبببببببححددرسعععففکککممنننلررسححسرحاایییووییحسسکببجطفقلمییرودصگویزعکبپتریفقنااببببپپپپببببتتتتتتتتتتتتففففححححححححچچچچچچچچددددددددژژررککککگگگگگگگگگگگگننننننههههههههههییییءاااووااییییااببببتتتتثثثثججججححححخخخخددذذررززسسسسششششصصصصضضضضططططظظظظععععغغغغففففققققککککللللممممننننههههوویییییییکی"" '
        )

        self.redundant_space_patterns = [
            (r" {2,}", " "),
            (r"\n{3,}", "\n\n"),
            (r"\u200c{2,}", "\u200c"),
            (r"\u200c{1,} ", " "),
            (r" \u200c{1,}", " "),
            (r"\b\u200c*\B", ""),
            (r"\B\u200c*\b", ""),
            (r"[ـ\r]", ""),
        ]

    def normalize(self, text):
        normalized_text = text.translate(str.maketrans(self.translation_src, self.translation_dst))

        for pattern, replacement in self.redundant_space_patterns:
            normalized_text = re.sub(pattern, replacement, normalized_text)

        return normalized_text



import re

class WordTokenizer:
    """
    Kurdish Punctuation-based Tokenizer class.
    """

    def __init__(self):
        # Define Kurdish punctuation characters and patterns
        self.punctuation = r"!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~،؛؟«»“”"
        self.pattern = re.compile(rf"(\s+|[{self.punctuation}])")

    def tokenize(self, text):
        """
        Tokenizes the given Kurdish text based on punctuation and spaces.
        Returns a list of tokens.
        """
        # Split the text based on the pattern
        tokens = re.split(self.pattern, text)

        # Filter out empty tokens and strip extra spaces
        tokens = [token.strip() for token in tokens if token.strip()]

        return tokens






import aamraz

# Normalization
normalizer= aamraz.Normalizer()
sample_sentence="قڵبە‌کە‌م‌ بە‌  کوردی‌  قسە‌ دە‌کات‌."
normalized_sentence=normalizer.normalize(sample_sentence)
print(normalized_sentence)

# Tokenization
tokenizer = aamraz.WordTokenizer()
sample_sentence="زوانی له دربره"
tokens = tokenizer.tokenize(sample_sentence)
print(tokens)

# Embedding
model_path = 'kurdish_fasttext_skipgram_dim300_v1.bin'
embedding_model = aamraz.EmbeddingModel(model_path, dim=50)

sample_word="ئامراز"
sample_sentence="زوانی له دربره"

word_vector = embedding_model.word_embedding(sample_word)
sentence_vector = embedding_model.sentence_embedding(sample_sentence)

print(word_vector)
print(sentence_vector)


import fasttext
import fasttext.util
import numpy as np


class EmbeddingModel:
    def __init__(self, model_path, dim=300):
        """
        Initialize the EmbeddingModel with a FastText model.

        Parameters:
            model_path (str): The path to the FastText model file.
            dim (int): The dimension to reduce the model to (default is 300).
        """
        self.model = fasttext.load_model(model_path)
        fasttext.util.reduce_model(self.model, dim)

    def word_embedding(self, word):
        """
        Get the word vector for a given word.

        Parameters:
            word (str): The word to get the embedding for.

        Returns:
            np.ndarray: The word vector.
        """
        word_vector = self.model.get_word_vector(word)
        return word_vector

    def sentence_embedding(self, sentence):
        """
        Get the sentence vector by averaging the word vectors of the words in the sentence.

        Parameters:
            sentence (str): The sentence to get the embedding for.

        Returns:
            np.ndarray: The sentence vector.
        """
        words = sentence.split()
        word_vectors = [self.model.get_word_vector(word) for word in words]
        sentence_vector = np.mean(word_vectors, axis=0)
        return sentence_vector


from setuptools import setup, find_packages

setup(
    name='aamraz',
    version='0.0.5',
    author='Mohammad Mahmoodi Varnamkhasti',
    author_email='research@amzmohammad.com',
    description='This project is a collection of Natural Language Processing tools for Kurdish Language.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',  # Change to 'text/x-rst' if using reStructuredText
    url='https://github.com/MohammadDevelop/Aamraz',  # URL to your project
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        'numpy>=2.1.0',
        'fasttext>=0.9.3',
    ],
)